Summary: A collection of SNMP protocol tools from UC-Davis.
Name: ucd-snmp
Version: 4.1.1
Release: 2
Copyright: BSDish
Group: System Environment/Daemons
Source0: ftp://ucd-snmp.ucdavis.edu/ucd-snmp-%{version}.tar.gz
Source1: ucd-snmpd.init
Source2: ucd-snmp.redhat.conf

BuildRoot: /var/tmp/ucd-snmp-root
Prereq: /sbin/chkconfig
Obsoletes: cmu-snmp

%description
SNMP (Simple Network Management Protocol) is a protocol used for
network management (hence the name).  The UCD-SNMP project includes
various SNMP tools: an extensible agent, an SNMP library, tools for
requesting or setting information from SNMP agents, tools for
generating and handling SNMP traps, a version of the netstat command
which uses SNMP, and a Tk/Perl mib browser.  This package contains the
snmpd and snmptrapd daemons, documentation, etc.

Install the ucd-snmp package if you need network management tools.
You will probably also want to install the ucd-snmp-utils package,
which contains UCD-SNMP utilities.

%package utils
Group: Applications/System
Summary: Network management utilities using SNMP, from the UCD-SNMP project.
Requires: ucd-snmp
Obsoletes: cmu-snmp-utils

%description utils
The ucd-snmp package contains various utilities for use with the
UCD-SNMP network management project.

Install this package if you need utilities for managing your network
using the SNMP protocol.  You'll also need to install the ucd-snmp
package.

%package devel
Group: Development/Libraries
Summary: The development environment for the UCD-SNMP project.
Requires: ucd-snmp
Obsoletes: cmu-snmp-devel

%description devel
The ucd-snmp-devel package contains the development libraries and
header files for use with the UCD-SNMP project's network management
tools.

Install the ucd-snmp-devel package if you would like to develop
applications for use with the UCD-SNMP project's network management
tools. You'll also need to have the ucd-snmp and ucd-snmp-utils
packages installed.

%prep
%setup -q

find . -type f | xargs perl -pi -e "s|/usr/local/bin/perl5|/usr/bin/perl|g"
find . -type f | xargs perl -pi -e "s|/usr/local/bin/perl|/usr/bin/perl|g"

%build

# First build the static library
# XXX remove privacy support?
%configure \
	--with-cflags="$RPM_OPT_FLAGS"			\
	--with-ldflags="-s" 				\
	--with-sys-location="Unknown"			\
	--with-logfile="/var/log/snmpd.log"		\
	--with-persistent-directory="/var/ucd-snmp"	\
	--with-mib-modules="host"			\
	--with-libwrap					\
	--sysconfdir=/etc				\
	--with-sys-contact="root@localhost"

# build static libsnmp.a
make -C snmplib libsnmp.a
mv snmplib/libsnmp.a .
make -C snmplib clean

# build static libucdagent.a and libucdmibs.a
make -C agent libucdmibs.a
make -C agent libucdagent.a
mv agent/libucdmibs.a .
mv agent/libucdagent.a .
make -C agent clean

# Now configure everything to build with a shared library
# XXX remove privacy support?
%configure --enable-shared				\
	--with-cflags="$RPM_OPT_FLAGS"			\
	--with-ldflags="-s" 				\
	--with-sys-location="Unknown"			\
	--with-logfile="/var/log/snmpd.log"		\
	--with-persistent-directory="/var/ucd-snmp"	\
	--with-mib-modules="host"			\
	--with-libwrap					\
	--sysconfdir=/etc				\
	--with-sys-contact="root@localhost"

# XXX Grrr -- build shared library with soname versioning
make -C snmplib				\
	SHLIB_EXTENSION=so.0.%{version}	\
	SHLIB_CFLAGS="-fpic"		\
	SHLIB_LD_CMD="gcc -shared -Wl,-soname -Wl,libsnmp.so.0 -o"	\
	RANLIB=/bin/echo		\
	libsnmp.so.0.%{version}
ln -sf libsnmp.so.0.%{version} snmplib/libsnmp.so.0
ln -sf libsnmp.so.0 snmplib/libsnmp.so

make -C agent				\
	SHLIB_EXTENSION=so.0.%{version}	\
	SHLIB_CFLAGS="-fpic"		\
	SHLIB_LD_CMD="gcc -shared -Wl,-soname -Wl,libucdmibs.so.0 -o"	\
	RANLIB=/bin/echo		\
	libucdmibs.so.0.%{version}
ln -sf libucdmibs.so.0.%{version} agent/libucdmibs.so.0
ln -sf libucdmibs.so.0 agent/libucdmibs.so

make -C agent				\
	SHLIB_EXTENSION=so.0.%{version}	\
	SHLIB_CFLAGS="-fpic"		\
	SHLIB_LD_CMD="gcc -shared -Wl,-soname -Wl,libucdagent.so.0 -o"	\
	RANLIB=/bin/echo		\
	libucdagent.so.0.%{version}
ln -sf libucdagent.so.0.%{version} agent/libucdagent.so.0
ln -sf libucdagent.so.0 agent/libucdagent.so

# XXX Finally ...
make LDFLAGS="-Wl,-rpath -Wl,/usr/lib" all

%install
rm -rf $RPM_BUILD_ROOT

make	prefix=$RPM_BUILD_ROOT/usr	\
	exec_prefix=$RPM_BUILD_ROOT/usr \
	persistentdir=$RPM_BUILD_ROOT/var/ucd-snmp \
	PERSISTENT_DIRECTORY=$RPM_BUILD_ROOT/var/ucd-snmp \
	install 

# XXX Install hand-crafted libraries
install -m 0644 libsnmp.a $RPM_BUILD_ROOT/usr/lib
install -m 0644 libucdagent.a $RPM_BUILD_ROOT/usr/lib
install -m 0644 libucdmibs.a $RPM_BUILD_ROOT/usr/lib

install -m 0755 snmplib/libsnmp.so.0.%{version} $RPM_BUILD_ROOT/usr/lib
install -m 0755 agent/libucdagent.so.0.%{version} $RPM_BUILD_ROOT/usr/lib
install -m 0755 agent/libucdmibs.so.0.%{version} $RPM_BUILD_ROOT/usr/lib

# XXX just in case
{ pushd $RPM_BUILD_ROOT/usr/lib
  rm -f libsnmp.so.0
  ln -s libsnmp.so.0.%{version} libsnmp.so.0
  rm -f libsnmp.so
  ln -s libsnmp.so.0 libsnmp.so

  rm -f libucdagent.so.0
  ln -s libucdagent.so.0.%{version} libucdagent.so.0
  rm -f libucdagent.so
  ln -s libucdagent.so.0 libucdagent.so

  rm -f libucdmibs.so.0
  ln -s libucdmibs.so.0.%{version} libucdmibs.so.0
  rm -f libucdmibs.so
  ln -s libucdmibs.so.0 libucdmibs.so

  popd
}

install -d $RPM_BUILD_ROOT/etc/snmp
install -m 644 %SOURCE2 $RPM_BUILD_ROOT/etc/snmp/snmpd.conf
#install -m 644 /dev/null $RPM_BUILD_ROOT/etc/snmp/snmpd.local.conf

install -d $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m 755 %SOURCE1 $RPM_BUILD_ROOT/etc/rc.d/init.d/snmpd

# Strip binaries
strip $RPM_BUILD_ROOT/usr/bin/* || :
strip $RPM_BUILD_ROOT/usr/sbin/* || :

%post
/sbin/ldconfig
/sbin/chkconfig --add snmpd 
#if [ ! -f /etc/snmpd.agentinfo ]; then
#  touch /etc/snmpd.agentinfo
#fi

%preun
/sbin/ldconfig
if [ $1 = 0 ]; then
   /sbin/chkconfig --del snmpd
fi

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc	AGENT.txt COPYING ChangeLog EXAMPLE.conf FAQ NEWS PORTING README* TODO bug-report local

%dir	/etc/snmp
%config(missingok) /etc/snmp/snmpd.conf
#%config(missingok) /etc/snmp/snmpd.local.conf

%config /etc/rc.d/init.d/snmpd

%dir	/usr/share/snmp
%dir	/usr/share/snmp/mibs
%attr(0644,root,root)	/usr/share/snmp/mibs/*

/usr/lib/libsnmp.so.0.%{version}
/usr/lib/libucdagent.so.0.%{version}
/usr/lib/libucdmibs.so.0.%{version}

/usr/sbin/snmpd
/usr/sbin/snmptrapd
%attr(0644,-,-)	/usr/man/man1/snmpd.1*
%attr(0644,-,-)	/usr/man/man5/snmp.conf.5*
%attr(0644,-,-)	/usr/man/man5/snmp_config.5*
%attr(0644,-,-)	/usr/man/man5/snmpd.conf.5*
%attr(0644,-,-)	/usr/man/man5/snmptrapd.conf.5*
%attr(0644,-,-)	/usr/man/man5/variables.5*
%attr(0644,-,-)	/usr/man/man8/snmptrapd.8*

%files utils
%defattr(-,root,root,-)
/usr/bin/encode_keychange
/usr/bin/snmpbulkget
/usr/bin/snmpbulkwalk
#/usr/bin/snmpcheck
/usr/bin/snmpdelta
/usr/bin/snmpget
/usr/bin/snmpgetnext
/usr/bin/snmpnetstat
/usr/bin/snmpset
/usr/bin/snmpstatus
/usr/bin/snmptable
/usr/bin/snmptest
/usr/bin/snmptranslate
/usr/bin/snmptrap
/usr/bin/snmpusm
/usr/bin/snmpwalk
#/usr/bin/tkmib

%attr(0644,-,-)	/usr/man/man1/snmpbulkwalk.1*
%attr(0644,-,-)	/usr/man/man1/snmpbulkget.1*
%attr(0644,-,-)	/usr/man/man1/snmpcmd.1*
%attr(0644,-,-)	/usr/man/man1/snmpdelta.1*
%attr(0644,-,-)	/usr/man/man1/snmpget.1*
%attr(0644,-,-)	/usr/man/man1/snmpgetnext.1*
%attr(0644,-,-)	/usr/man/man1/snmpnetstat.1*
%attr(0644,-,-)	/usr/man/man1/snmpset.1*
%attr(0644,-,-)	/usr/man/man1/snmpstatus.1*
%attr(0644,-,-)	/usr/man/man1/snmptable.1*
%attr(0644,-,-)	/usr/man/man1/snmptest.1*
%attr(0644,-,-)	/usr/man/man1/snmptranslate.1*
%attr(0644,-,-)	/usr/man/man1/snmptrap.1*
%attr(0644,-,-)	/usr/man/man1/snmpusm.1*
%attr(0644,-,-)	/usr/man/man1/snmpwalk.1*

%files devel
%defattr(0644,root,root,0755)
/usr/lib/libsnmp.so
/usr/lib/libsnmp.a
/usr/lib/libucdagent.so
/usr/lib/libucdagent.a
/usr/lib/libucdmibs.so
/usr/lib/libucdmibs.a

/usr/include/ucd-snmp
%attr(0644,-,-)	/usr/man/man3/*

%changelog
* Sun Feb 27 2000 Jeff Johnson <jbj@redhat.com>
- default config was broken (from Wes Hardaker) (#9752)

* Sun Feb 13 2000 Jeff Johnson <jbj@redhat.com>
- compressed man pages.

* Fri Feb 11 2000 Wes Hardaker <wjhardaker@ucdavis.edu>
- update to 4.1.1

* Sat Feb  5 2000 Florian La Roche <Florian.LaRoche@redhat.com>
- change %postun to %preun

* Thu Feb 3 2000 Elliot Lee <sopwith@redhat.com>
- Don't ship tkmib, since we don't ship the perl modules needed to run it.
(Bug #4881)

* Tue Aug 31 1999 Jeff Johnson <jbj@redhat.com>
- default config permits RO access to system group only (Wed Hardaker).

* Sun Aug 29 1999 Jeff Johnson <jbj@redhat.com>
- implement suggestions from Wes Hardaker.

* Fri Aug 27 1999 Jeff Johnson <jbj@redhat.com>
- stateless access to rpm database.

* Wed Aug 25 1999 Jeff Johnson <jbj@redhat.com>
- update to 4.0.1.

* Mon Aug 16 1999 Bill Nottingham <notting@redhat.com>
- initscript munging

* Sat Jun 12 1999 Jeff Johnson <jbj@redhat.com>
- update to 3.6.2 (#3219,#3259).
- add missing man pages (#3057).

* Thu Apr  8 1999 Wes Hardaker <wjhardaker@ucdavis.edu>
- fix Source0 location.
- fix the snmpd.conf file to use real community names.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 3)

* Fri Mar 19 1999 Preston Brown <pbrown@redhat.com>
- upgrade to 3.6.1, fix configuration file stuff.

* Wed Feb 24 1999 Preston Brown <pbrown@redhat.com>
- Injected new description and group.

* Tue Feb  2 1999 Jeff Johnson <jbj@redhat.com>
- restore host resources mib
- simplified config file
- rebuild for 6.0.

* Tue Dec 22 1998 Bill Nottingham <notting@redhat.com>
- remove backup file to fix perl dependencies

* Tue Dec  8 1998 Jeff Johnson <jbj@redhat.com>
- add all relevant rpm scalars to host resources mib.

* Sun Dec  6 1998 Jeff Johnson <jbj@redhat.com>
- enable libwrap (#253)
- enable host module (rpm queries over SNMP!).

* Mon Oct 12 1998 Cristian Gafton <gafton@redhat.com>
- strip binaries

* Fri Oct  2 1998 Jeff Johnson <jbj@redhat.com>
- update to 3.5.3.
- don't include snmpcheck until perl-SNMP is packaged.

* Thu Aug 13 1998 Jeff Johnson <jbj@redhat.com>
- ucd-snmpd.init: start daemon w/o -f.

* Tue Aug  4 1998 Jeff Johnson <jbj@redhat.com>
- don't start snmpd unless requested
- start snmpd after pcmcia.

* Sun Jun 21 1998 Jeff Johnson <jbj@redhat.com>
- all but config (especially SNMPv2p) ready for prime time

* Sat Jun 20 1998 Jeff Johnson <jbj@redhat.com>
- update to 3.5.

* Tue Dec 30 1997 Otto Hammersmith <otto@redhat.com>
- created the package... possibly replace cmu-snmp with this.
